@@ -1,19 +1,18 @@
 
  library(rcdd)
 
- A <- matrix(scan(), byrow = TRUE, nrow = 9)
-    0  1.000   -1    0    0    0
-    0  1.000   -1    0    0    0
-    0 -0.001    1    0    0    0
-    0 -0.001    0    1    0    0
-    0 -0.001    0    0    1    0
-    0 -0.001    0    0    0    1
-    1  1.000   -1   -1   -1   -1
-    1  0.300   -1   -1   -1    0
-    1  7.990   -1   -3   -5   -8
+ A <- rbind(
+    c(0,  1.000,   -1,    0,    0,    0),
+    c(0,  1.000,   -1,    0,    0,    0),
+    c(0, -0.001,    1,    0,    0,    0),
+    c(0, -0.001,    0,    1,    0,    0),
+    c(0, -0.001,    0,    0,    1,    0),
+    c(0, -0.001,    0,    0,    0,    1),
+    c(1,  1.000,   -1,   -1,   -1,   -1),
+    c(1,  0.300,   -1,   -1,   -1,    0),
+    c(1,  7.990,   -1,   -3,   -5,   -8))
 
- b <- scan()
-    0 0 0 0
+ b <- c(0, 0, 0, 0)
 
  out <- lpcdd(A, b)
  out
